@@ -102,19 +102,6 @@ class BaseIndividual():
     """
     Base class for individuals. This class is used as interface to the database.
     """
-    date_label_translation = {
-        'Calculated': '{symbol}\xa0berechnet\xa0{datum}',
-        'Estimated': '{symbol}\xa0geschätzt\xa0{datum}',
-        'Estimated (min 25 at marriage)': '{symbol}\xa0geschätzt\xa0{datum}',
-        'Estimated (max age 75)': '{symbol}\xa0geschätzt\xa0{datum}',
-        'Estimated (max age 100)': '{symbol}\xa0geschätzt\xa0{datum}',
-        'Estimated (min 1 after parents marriage)': '{symbol}\xa0geschätzt\xa0{datum}',
-        'Still alive': '',
-        'About': '{symbol}\xa0etwa\xa0{datum}',
-        'Before': '{symbol}\xa0vor\xa0{datum}',
-        'After': '{symbol}\xa0nach\xa0{datum}',
-        'YearPrecision': '{symbol}\xa0{datum}'
-    }
 
     def __init__(self, instances, individual_id):
         self._instances = instances
@@ -124,7 +111,7 @@ class BaseIndividual():
         self.child_of_family_id = []
         self.events = {}  # : events like birth or death
         self.graphical_representations = [] # : instances of graphical representations
-        self.images = {}  # : mapping of ordinal values to fotos of this individual
+        self.images = {}  # : mapping of ordinal values to photos of this individual
 
     def _initialize(self):
         self._marriage_family_ids = self._get_marriage_family_ids()
@@ -193,8 +180,8 @@ class BaseIndividual():
         if self.events['birth_or_christening']:
             event = self.events['birth_or_christening']
             if event['comment']:
-                string = self.date_label_translation[event['comment']].format(
-                    symbol='*', datum=str(event['date'].date().year))
+                string = self._instances.date_label_translation[event['comment']].format(
+                    symbol='*', date=str(event['date'].date().year))
                 # string += ' ' + self.events['birth_or_christening']['comment']
             else:
                 string += '*\xa0' + event['date'].date().strftime('%d.%m.%Y')
@@ -212,8 +199,8 @@ class BaseIndividual():
         if self.events['death_or_burial']:
             event = self.events['death_or_burial']
             if event['comment']:
-                string = self.date_label_translation[event['comment']].format(
-                    symbol='\u2020', datum=str(event['date'].date().year))
+                string = self._instances.date_label_translation[event['comment']].format(
+                    symbol='\u2020', date=str(event['date'].date().year))
                 # string += ' ' + self.events['birth_or_christening']['comment']
             else:
                 string += '\u2020\xa0' + event['date'].date().strftime('%d.%m.%Y')
@@ -282,6 +269,7 @@ class BaseIndividual():
 
     def get_child_of_family(self):
         return [self._instances[('f', family_id)] for family_id in self.child_of_family_id]
+    child_of_family = property(get_child_of_family)
 
     def has_graphical_representation(self):
         return len(self.graphical_representations) > 0
